;*****************************************************************************
;  Function which returns the initial HAM side for all collects in a directory (for the OBC).
;
;  Inputs:
;  1) directory -- directory containing dump files.
;  2) header_size -- (optional) number of lines in header.
;
;  Outputs:
;  1) ham -- array of initial HAM sides for a set of collects.
;  
;  v1 - 8/18/2008 - Jeff McIntire
;*****************************************************************************

FUNCTION initial_ham_side, directory,header_size

n_collect,directory,ncollect,type,0

; Get list of .dmp files from specified path. 
spawn,'ls -C1 '+directory+'*.dmp',list_files
nfile=N_ELEMENTS(list_files)
IF nfile EQ 0 THEN RETURN,0

count1=0
ham=intarr(ncollect)
FOR ifile=0, nfile-1 DO BEGIN

	b1=strsplit(list_files[ifile],'/',/Extract)
	b2=N_ELEMENTS(b1)
	b3=strmid(b1[b2-1],strpos(b1[b2-1],'/',/Reverse_Search)+10,2)
	b4=strmid(b1[b2-1],strpos(b1[b2-1],'/',/Reverse_Search)+18,2)
	IF b3 NE 'EV' THEN continue
	IF b4 NE 'I4' THEN continue

	; Header.
	header=strarr(1)

	; Read in the first HAM side per collect.
	ab=''
	openr,lun,list_files[ifile],/Get_Lun
	IF header_size[0] EQ 0 THEN goto,skiph
	FOR j=0, header_size[0]-1 DO BEGIN
		readf,lun,header
	ENDFOR
	skiph:
	readf,lun,ab
	a1=strsplit(ab,String(9B),/Extract)
	ham(count1)=a1(3)
	count1=count1+1
	Free_Lun,lun

	skip:
ENDFOR

RETURN,ham

END
