;*****************************************************************************
;  Function which returns the number of collects in a given directory.
;
;  Inputs:
;  1) directory -- directory containing dump files.
;
;  Outputs:
;  1) ncollect -- number of collects.
;  2) type -- band range under consideration (RSB, TEB, ...).
;  3) flag -- 0 for EV and 1 for OBC.
;  
;  v1 - 4/14/2008 - Jeff McIntire
;  v2 - 7/15/2008 - Jeff McIntire
;*****************************************************************************

PRO n_collect, directory, ncollect,type,flag

; Get list of .dmp files from specified path. 
spawn,'ls -C1 '+directory+'*.dmp',list_files
nfile=N_ELEMENTS(list_files)
IF nfile EQ 0 THEN BEGIN
	ncollect=0
	goto,skipout
ENDIF

count1=0
count2=0
count3=0
count4=0
count5=0
FOR ifile=0, nfile-1 DO BEGIN

	; Pick out EV files.
	b1=strsplit(list_files[ifile],'/',/Extract)
	b2=N_ELEMENTS(b1)
	b3=strmid(b1[b2-1],strpos(b1[b2-1],'/',/Reverse_Search)+10,2)
	IF flag EQ 0 AND b3 NE 'EV' THEN goto,skip_ev
	IF flag EQ 1 AND b3 NE 'OB' THEN goto,skip_obc

	; Count the numbers of M1, M12, and M14 files.
	IF flag EQ 0 THEN b4=strmid(b1[b2-1],strpos(b1[b2-1],'/',/Reverse_Search)+18,3)
	IF flag EQ 1 THEN b4=strmid(b1[b2-1],strpos(b1[b2-1],'/',/Reverse_Search)+19,3)
	IF b4 EQ 'M1' THEN count1=count1+1
	IF b4 EQ 'M11' THEN count2=count2+1
	IF b4 EQ 'M12' THEN count3=count3+1
	IF b4 EQ 'M14' THEN count4=count4+1
	IF b4 EQ 'M13' THEN count5=count5+1

	skip_ev:
	skip_obc:
ENDFOR

; Determine the number of collects.
IF count1 GT 0 THEN BEGIN
	ncollect=count1
	IF count2 EQ 0 THEN type='VisNIR'
	goto,skip_VisNIR
ENDIF
IF count2 GT 0 THEN BEGIN
	ncollect=count2
	IF count3 EQ 0 THEN type='RSB'
	goto,skip_RSB
ENDIF
IF count3 GT 0 THEN BEGIN
	ncollect=count3
	IF count4 EQ 0 THEN type='SMWIR'
	IF count4 GT 0 THEN type='TEB'
	goto,skip_SMWIR
ENDIF
IF count4 GT 0 THEN BEGIN
	ncollect=count4
	type='LWIR'
	goto,skip_LWIR
ENDIF
IF count5 GT 0 THEN BEGIN
	ncollect=count5
	type='M13'
ENDIF
skip_VisNIR:
skip_RSB:
skip_TEB:
skip_SMWIR:
skip_LWIR:

skipout:
END
